#!/bin/bash
# Docker entrypoint of the docker image of the CES Slurm Simulator
#
# This script was adapted from https://github.com/jafreck/docker-ubuntu-slurm/blob/master/docker-entrypoint.sh
# and also from https://github.com/giovtorres/docker-centos7-slurm/
#
# BSC-CNS - Earth Sciences
# Manuel Giménez de Castro Marciani
# 2023

function error_with_msg {
    if [[ "$count" -eq 0 ]]
    then
        echo
        echo >&2 "$1"
        exit 1
    fi
}

function check_running_status {
    for count in {10..0}; do
        STATUS=$(/usr/bin/supervisorctl status $1 | awk '{print $2}')
        echo "docker-entrypoint.sh: $1 is in the $STATUS state."
        if [[ "$STATUS" = "RUNNING" ]]
        then
            break
        else
            sleep 1
        fi
    done
}

function check_slurmdbd_spooling_up {
    for count in {10..0}; do
        STATUS=$(tail -1 /var/log/supervisor/slurmdbd.log)
	if [[ "$STATUS" = "" ]]; then
	    break
	else
            sleep 1
	fi
    done
}

function check_stopped {
    for count in {30..0}; do
        if echo "SELECT 1" | $1 &> /dev/null; then
            sleep 1
        else
            break
        fi
    done
    if [[ "$count" -eq 0 ]]; then
        echo >&2 $1" did not stop"
        exit 1
    fi
}

function start_service {
    echo "docker-entrypoint.sh: Starting $1"
    /usr/bin/supervisorctl start $1
    check_running_status $1
}

function stop_service {
    echo "docker-entrypoint.sh: Stopping $1"
    /usr/bin/supervisorctl stop $1
    check_stopped $1
}

if [ ! -d "/var/lib/mysql/slurm_acct_db" ]; then
    /usr/bin/mysqld_safe --datadir='/var/lib/mysql' &

    for count in {30..0}; do
	if echo "SELECT 1" | mysql &> /dev/null; then
            break
        fi
        echo "docker-entrypoint.sh: Starting MariaDB to create Slurm account database"
        sleep 1
    done

    if [[ "$count" -eq 0 ]]; then
        echo >&2 "MariaDB did not start"
        exit 1
    fi

    echo "docker-entrypoint.sh: Creating Slurm acct database"
    mysql -NBe "CREATE DATABASE slurm_sacct_db"
    mysql -NBe "GRANT USAGE ON *.* to 'root'@'localhost'"
    mysql -NBe "GRANT ALL PRIVILEGES on slurm_sacct_db.* to 'root'@'localhost'"
    mysql -NBe "FLUSH PRIVILEGES"
    # import the dumped database onto here
    status=$(mysql -p slurm_sacct_db < /opt/ces_slurm_simulator_tools/slurm_sacct_db.sql)
    if [[ $status == 1 ]]; then
        echo "docker-entrypoint.sh: Failed to import database. Check the format of the file."
	exit 1
    fi
    echo "docker-entrypoint.sh: Slurm acct database created."

    killall mysqld
    check_stopped mysqld
fi

echo "docker-entrypoint.sh: Starting supervisord process manager"
/usr/bin/supervisord --configuration /etc/supervisord.conf

# check if supervisord has launched mysqld
check_running_status mysqld

python3 run_simulation.py workloads/workload.swf $@  

